@@ -185,6 +185,8 @@ def points_to_cf(pts: Union[xr.DataArray, Sequence]):
         A Dataset with variables 'x', 'y', 'crd_x', 'crd_y', 'node_count' and 'geometry_container'.
         The coordinates of MultiPoint instances are their first point.
     """
+    from shapely.geometry import MultiPoint
+
     if isinstance(pts, xr.DataArray):
         dim = pts.dims[0]
         coord = pts[dim] if dim in pts.coords else None
@@ -195,7 +197,10 @@ def points_to_cf(pts: Union[xr.DataArray, Sequence]):
 
     x, y, node_count, crdX, crdY = [], [], [], [], []
     for pt in pts:
-        xy = np.atleast_2d(np.array(pt))
+        if isinstance(pt, MultiPoint):
+            xy = np.concatenate([p.coords for p in pt.geoms])
+        else:
+            xy = np.atleast_2d(pt.coords)
         x.extend(xy[:, 0])
         y.extend(xy[:, 1])
         node_count.append(xy.shape[0])
